/// <reference types="react" />
import * as React from 'react';
import Header from './header';
import Row, { Column } from './row';
import { DataSource, IEditable, EditableDataSource } from './datasource';
/**
 * Base Table class
 *
 * Since React doesn't allow type parameters to be set in jsx, i'd suggest the creation of a custom class which extends this base class and includes a type parameter
 * @export
 * @class Table
 * @extends {React.Component<ITableProps<T>, Partial<ITableState>>}
 * @template T
 */
export declare class Table<T> extends React.Component<ITableProps<T>, Partial<ITableState<T>>> {
    constructor(props: ITableProps<T>);
    getData(props: any): Promise<void>;
    render(): JSX.Element;
    setSort(key: string): void;
}
export default Table;
export interface ITableProps<T> {
    data?: T[];
    dataSource?: DataSource<T>;
    primaryKey: keyof T;
    /**
     * Configure columns. Non-configured columns wont be displayed
     *
     * @type {IFieldConfig<T, keyof T>}
     * @memberOf ITableProps
     */
    fieldConfig: IFieldConfig<T, keyof T>;
    autosize?: number;
    className?: string;
    gridSize?: number;
    headerClassName?: string;
    headerColumnClassName?: string;
    rowClassName?: string;
    columnClassName?: string;
    filteredColumnClassName?: string;
    /**
     * Specifies wether rowClasses and columnClasses should be applied to Header
     *
     * Default: true
     * @type {boolean}
     * @memberOf ITableProps
     */
    addClassesToHeader?: boolean;
    sortable?: boolean;
    tableActions?: Actions;
    rowActions?: Actions;
    onRowAction?(rowKey: string, action: string): void;
    onRowSelected?(rowKey: string): void;
    onCellClick?(rowKey: string, cellKey: string): void;
}
export declare type Actions = {
    [key: string]: string;
};
export { Row, Header, Column, DataSource, IEditable, EditableDataSource };
export interface IFieldConfig<T, K extends keyof T> {
    [key: string]: Partial<IField<T[K]>>;
}
export interface IField<T> {
    getCell(rowKey: string, value: T): string | JSX.Element;
    /**
     * Controls visibility of column
     *
     * @type {boolean}
     * @memberOf IField
     */
    hidden?: boolean;
    /**
     * Controls sortability of column
     *
     * @type {boolean}
     * @memberOf IField
     */
    sortable?: boolean;
    /**
     * Value of headercolumn
     *
     * @type {(string | React.ReactInstance)}
     * @memberOf IField
     */
    header?: string | React.ReactInstance;
    /**
     * Sort function for field
     *
     * @memberOf IField
     */
    sortFunction?: (a: T, b: T, asc: number) => number;
    /**
     * Controls display order of columns
     * The smaller the number, the smaller the index
     *
     * Default: 0
     * @type {number}
     * @memberOf IField
     */
    order?: number;
    /**
     * Size of column
     *
     * @type {number}
     * @memberOf IField
     */
    size?: number;
}
export interface ITableState<T> {
    sortDir: 'asc' | 'desc';
    sortField: string;
    rows: T[];
}
